@@ -79,16 +79,16 @@ setMethodS3("saveCache", "default", function(object, key=NULL, sources=NULL, suf
 
   # Save 'identifier'
   identifier <- "Rcache v0.1.7 (R package R.cache by Henrik Bengtsson)";
-  if (nchar(identifier) > 64)
+  if (nchar(identifier) > 64L)
     throw("Internal error. Identifier is too long: ", identifier);
-  tail <- paste(rep(" ", 64-nchar(identifier)), collapse="");
+  tail <- paste(rep(" ", times=64L-nchar(identifier)), collapse="");
   identifier <- paste(identifier, tail, sep="");
-  writeChar(con=fh, identifier, nchars=64);
+  writeChar(con=fh, identifier, nchars=64L);
 
   # Save 'comment'
   if (is.null(comment))
     comment <- "";
-  writeBin(con=fh, nchar(comment), size=4);
+  writeBin(con=fh, nchar(comment), size=4L);
   writeChar(comment, con=fh, nchars=nchar(comment));
 
   # Save 'sources'
